<?php
/**
 * Add admin notice
*/

add_action( 'admin_notices', 'finaco_admin_notice'  );
add_action( 'wp_ajax_dismiss_admin_notice', 'finaco_dismiss_admin_notice' );
add_action( 'admin_enqueue_scripts', 'finaco_welcome_static'  );

 
function finaco_admin_notice() {
	if ( is_admin() && ! get_user_meta( get_current_user_id(), 'welcome_box' ) ) {
		?>
		
		
		
		<div class="updated notice is-dismissible finaco-admin-notice" data-notice="welcome_box">
			<h1><?php
			$theme_info = wp_get_theme();
			printf( esc_html__('Congratulations, Welcome to %1$s Theme', 'finaco'), esc_html( $theme_info->Name ), esc_html( $theme_info->Version ) ); ?>
			</h1>
			<p><?php echo sprintf( esc_html__("Thank you for choosing finaco theme. To take full advantage of the complete features of the theme, you have to go to our %1\$s welcome page %2\$s.", "finaco"), '<a href="' . esc_url( admin_url( 'themes.php?page=finaco-welcome' ) ) . '">', '</a>' ); ?></p>
			
			<p><a href="<?php echo esc_url( admin_url( 'themes.php?page=finaco-welcome' ) ); ?>" class="button button-blue-secondary button_info" style="text-decoration: none;"><?php echo esc_html__('Get started with finaco','finaco'); ?></a></p>
		</div>
		
		
		<?php
	}
}


/**
 * Dismiss admin notice
 */
function finaco_dismiss_admin_notice() {

	// Nonce check.
	check_ajax_referer( 'finaco_dismiss_admin_notice', 'nonce' );

	// Bail if user can't edit theme options.
	if ( ! current_user_can( 'edit_theme_options' ) ) {
		wp_send_json_error();
	}

	$notice = isset( $_POST['notice'] ) ? sanitize_text_field( wp_unslash( $_POST['notice'] ) ) : '';

	if ( $notice ) {
		update_user_meta( get_current_user_id(), $notice, true );
		wp_send_json_success();
	}

	wp_send_json_error();
}

/**
 * Load welcome screen script and css
 */
function finaco_welcome_static() {
	// Dismiss admin notice.
	wp_enqueue_script(
		'finaco-dismiss-admin-notice',
		get_template_directory_uri() . '/inc/admin/js/dismiss-admin-notice.js',
		'1.0',
		true
	);
	
	wp_enqueue_script(
		'finaco-install-demo',
		get_template_directory_uri() . '/inc/admin/js/install-demo.js',
		array('updates'),
		'1.0',
		true
	);
	

	wp_localize_script(
		'finaco-dismiss-admin-notice',
		'finaco_dismiss_admin_notice',
		array(
			'nonce' => wp_create_nonce( 'finaco_dismiss_admin_notice' ),
		)
	);

	// Welcome screen style.
	wp_enqueue_style('finaco-admin-styles', get_template_directory_uri().'/inc/admin/css/finaco-welcome.css');

}



add_action('admin_menu', 'finaco_welcome_page');


// finaco welcome page register
function finaco_welcome_page() {
	$wpazure_page_title =  apply_filters( 'finaco_menu_page_title', __( 'Finaco Options', 'finaco' ) );
    add_theme_page('finaco Theme Options', $wpazure_page_title, 'manage_options', 'finaco-welcome', 'finaco_settings_page');
}

function finaco_settings_page(){
	?>
  <div class="finaco-admin wrap">
  	<?php	do_action( 'finaco_settings_content' ); ?>
  </div><!-- /.wrap -->
  <?php
}


/**
 * Customizer settings link
 */
function finaco_info_customizer_settings() {
	$customizer_settings = apply_filters(
		'finaco_panel_customizer_settings',
		array(
			'upload_logo' => array(
				'icon'     => 'dashicons dashicons-format-image',
				'name'     => __( 'Upload Logo', 'finaco' ),
				'type'     => 'control',
				'setting'  => 'custom_logo',
				'required' => '',
			),
			
			'home_section' => array(
				'icon'     => 'dashicons dashicons-admin-settings',
				'name'     => __( 'Home section settings', 'finaco' ),
				'type'     => 'panel',
				'setting'  => 'homepage_sections',
				'required' => '',
			),
			
			'widget' => array(
				'icon'     => 'dashicons dashicons-tagcloud',
				'name'     => __( 'Widgets', 'finaco' ),
				'type'     => 'section',
				'setting'  => 'sidebar-widgets-top-header-left',
				'required' => '',
			),
		)
	);

	return $customizer_settings;
}


add_action( 'finaco_settings_content', 'finaco_welcome_render_options_page' );

function finaco_welcome_render_options_page() {  

$finaco_url = 'https://wpazure.com';
			?>
	<div class="finaco-options-wrap admin-welcome-screen">


				<div class="finaco-enhance">
					<div class="finaco-info-container">
						<div class="finaco-enhance-content">
							<div class="finaco-enhance__column finaco-bundle">
								<h3><?php esc_html_e( 'Link to Customizer Settings', 'finaco' ); ?></h3>
								<div class="finaco-quick-setting-section">
									<ul class="finaco-list">
									<?php
									foreach ( finaco_info_customizer_settings() as $key ) {
										$url = get_admin_url() . 'customize.php?autofocus[' . $key['type'] . ']=' . $key['setting'];

										$disabled = '';
										$title    = '';
										if ( '' !== $key['required'] && ! class_exists( $key['required'] ) ) {
											$disabled = 'disabled';

											/* translators: 1: Class name */
											$title = sprintf( __( '%s not activated.', 'finaco' ), ucfirst( $key['required'] ) );

											$url = '#';
										}
										?>

										<li class="link-to-customie-item <?php echo esc_attr( $disabled ); ?>" title="<?php echo esc_attr( $title ); ?>">
											<a class="wst-quick-setting-title wp-ui-text-highlight" href="<?php echo esc_url( $url ); ?>" target="_blank" rel="noopener">
												<span class="<?php echo esc_attr( $key['icon'] ); ?>"></span>
												<?php echo esc_html( $key['name'] ); ?>
											</a>
										</li>

									<?php } ?>
									</ul>
									
									
								</div>
							</div>

								<div class="finaco-enhance__column finaco-pro-featured pro-featured-list">
									<h3>
										<a class="finaco-learn-more wp-ui-text-highlight" href="https://www.wpazure.com/finaco-pro/" target="_blank"><?php esc_html_e( 'Get The Finaco Pro Version!', 'finaco' ); ?></a>
									</h3>

									<div class="finaco-quick-setting-section">
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Top Header', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Multiple Slider Layout and Video Background', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Multiple Header & Footer Layout', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'About section', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Unlimited Servives', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Unlimited Portfolio', 'finaco' ); ?>
											</strong>
											
										</div>
										
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Unlimited Testimonial', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Pricing Section', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Team section', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Client section', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( '17 Page Templates', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Multiple Portfolio Layouts', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Multiple Blog Layouts', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Theme section Layout Manager', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Theme Section Hooks', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Theme settings', 'finaco' ); ?>
											</strong>
											
										</div>
										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Typography', 'finaco' ); ?>
											</strong>
											
										</div>

										<div class="pro-featured-item">
											<strong class="pro-featured-name">
												<?php esc_html_e( 'Read more about pro', 'finaco' ); ?>
											</strong>
											<p>
										<a href="<?php echo esc_url( $finaco_url ); ?>/finaco-pro" class="finaco-button button-primary" target="_blank"><?php esc_html_e( 'Read more', 'finaco' ); ?></a>
									</p>
										</div>
										
									</div>
								</div>
						
							<?php do_action( 'finaco_pro_panel' ); ?>
						</div>

						<div class="finaco-enhance-sidebar">
							<?php do_action( 'finaco_pro_panel_sidebar' ); ?>

							<div class="finaco-enhance__column">
								<h3><?php esc_html_e( 'About Theme', 'finaco' ); ?></h3>

								<div class="finaco-quick-setting-section">
									<img src="<?php echo esc_url( FINACO_THEME_URI . 'images/banner.jpg' ); ?>" alt="finaco Banner" />

									<p>
										<?php esc_html_e( 'Finaco is a modern,responsive and fully customizable lightning fast WordPress theme for professionals. This theme comes with a stunning COOL & BEAUTIFUL LOOK, SERVICE SECTION, PORTFOLIO SECTION, TESTIMONIAL SECTION, WOOCOMMERCE PRODUCT SECTION, CALL TO ACTION SECTION, BLOG POST SECTION. ', 'finaco' ); ?>
									</p>

									<a href="<?php echo esc_url( admin_url( 'customize.php' ) ); ?>" class="finaco-button button-primary " target="_blank"><?php echo esc_html__( 'Go to customizer', 'finaco' ); ?></a>
		
								</div>
							</div>
							
							<div class="finaco-enhance__column">
								<h3><?php esc_html_e( 'Recommend Plugins', 'finaco' ); ?></h3>
								
								
								<?php
									$plugin_slug = 'wpazure-companion';
									$slug        = 'wpazure-companion/wpazure-companion.php';
									$redirect    = admin_url( 'admin.php?page=finaco-welcome' );
									$nonce       = add_query_arg(
										array(
											'action'        => 'activate',
											'plugin'        => rawurlencode( $slug ),
											'plugin_status' => 'all',
											'paged'         => '1',
											'_wpnonce'      => wp_create_nonce( 'activate-plugin_' . $slug ),
										),
										network_admin_url( 'plugins.php' )
									);

									// Check finaco Sites status.
									$type = 'install';
									if ( file_exists( ABSPATH . 'wp-content/plugins/' . $plugin_slug ) ) {
										$activate = is_plugin_active( $plugin_slug . '/wpazure-companion.php' ) ? 'activate' : 'deactivate';
										$type = $activate;
									}

									
									$button = '<a href="' . esc_url( admin_url( 'customize.php' ) ) . '" class="finaco-button " target="_blank">' . esc_html__( 'Plugin activated', 'finaco' ) . '</a>';

									
									if ( ! defined( 'WPAZURE_KIT_VERSION' ) ) {
										if ( 'deactivate' == $type ) {
											$button = '<a data-redirect="' . esc_url( $redirect ) . '" data-slug="' . esc_attr( $slug ) . '" class="finaco-button button finaco-active-now" href="' . esc_url( $nonce ) . '">' . esc_html__( 'Activate', 'finaco' ) . '</a>';
										} else {
											$button = '<a data-redirect="' . esc_url( $redirect ) . '" data-slug="' . esc_attr( $plugin_slug ) . '" href="' . esc_url( $nonce ) . '" class="finaco-button install-now button finaco-install-demo">' . esc_html__( 'Install Wpazure Companion', 'finaco' ) . '</a>';
										}
									}

									// Data.
									wp_localize_script(
										'finaco-install-demo',
										'finaco_install_demo',
										array(
											'activating' => esc_html__( 'Activating', 'finaco' ),
										)
									);
									?>
									<div class="finaco-quick-setting-section">
										<p>
											<?php echo $button; // WPCS: XSS ok. ?>
										</p>
									</div>

								
							</div>

							<div class="finaco-enhance__column">
								<h3><?php esc_html_e( 'Learn More', 'finaco' ); ?></h3>

								<div class="finaco-quick-setting-section">
									<p>
										<?php esc_html_e( 'Want to know more about finaco? Click on the below link to read full detail.', 'finaco' ); ?>
									</p>

									<p>
										<a href="<?php echo esc_url( $finaco_url ); ?>/finaco-lite/" class="finaco-button"><?php esc_html_e( 'Visit Us', 'finaco' ); ?></a>
									</p>
								</div>
							</div>
							
							
						</div>
					</div>
				</div>
			</div>
	
<?php }
